ByteStr

Struct ByteStr 

pub struct ByteStr { /* private fields */ }
Borrowed reference to a byte string. It provides similar functionality as str and [u8].

Implementations

Source

impl ByteStr

pub fn empty<'a>() -> &'a Self

Creates an empty ByteStr.

pub fn empty_mut<'a>() -> &'a mut Self

Creates an empty mutable ByteStr.

pub fn from_slice(bytes: &[u8]) -> &Self

Creates a ByteStr from a byte slice.

pub fn from_slice_mut(bytes: &mut [u8]) -> &mut Self

Create a mutable ByteStr from a byte slice.

pub unsafe fn from_raw_parts<'a>(ptr: *const u8, len: usize) -> &'a Self

Forms a ByteStr from a pointer and a length.

pub unsafe fn from_raw_parts_mut<'a>(ptr: *mut u8, len: usize) -> &'a mut Self

Forms a mutable ByteStr from a pointer and a length.

pub fn as_slice(&self) -> &[u8]

Converts self into a byte slice.

pub fn as_mut_slice(&mut self) -> &mut [u8]

Converts self into a mutable byte slice.

pub fn to_vec(&self) -> Vec<u8>

Copies the self into a Vec.

pub fn to_byte_string(&self) -> ByteString

Copies the self into a ByteString.

pub fn into_boxed_slice(self: Box<Self>) -> Box<[u8]>

Converts self into a boxed slice without clones or allocation.

pub fn into_vec(self: Box<Self>) -> Vec<u8>

Converts self into a vector without clones or allocation.

pub fn into_byte_string(self: Box<Self>) -> ByteString

Converts self into a ByteString without clones or allocation.

pub fn len(&self) -> usize

Returns the length of self.

pub fn is_empty(&self) -> bool

Returns true if the length of self is zero.

pub fn as_ptr(&self) -> *const u8

Converts self into a raw pointer that points to the first byte of the string.

pub fn as_mut_ptr(&mut self) -> *mut u8

Converts self into a mutable raw pointer that points to the first byte of the string.

pub fn get(&self, index: usize) -> Option<&u8>

Returns a reference to an element of the slice, or None if the index is out of bounds.

pub fn get_mut(&mut self, index: usize) -> Option<&mut u8>

Returns a mutable reference to an element of the slice, or None if the index is out of bounds.

pub fn first(&self) -> Option<&u8>

Returns a reference to the first byte of the string, or None if it is empty.

pub fn first_mut(&mut self) -> Option<&mut u8>

Returns a mutable reference to the first byte of the string, or None if it is empty.

pub fn last(&self) -> Option<&u8>

Returns a reference to the last byte of the string, or None if it is empty.

pub fn last_mut(&mut self) -> Option<&mut u8>

Returns a mutable reference to the last byte of the string, or None if it is empty.

pub fn split_first(&self) -> Option<(&u8, &ByteStr)>

Returns the first and all the rest of the bytes of the slice, or None if it is empty.

pub fn split_first_mut(&mut self) -> Option<(&mut u8, &mut ByteStr)>

Returns the first and all the rest of the bytes of the slice, or None if it is empty.

pub fn split_last(&self) -> Option<(&u8, &ByteStr)>

Returns the last and all the rest of the bytes of the slice, or None if it is empty.

pub fn split_last_mut(&mut self) -> Option<(&mut u8, &mut ByteStr)>

Returns the last and all the rest of the bytes of the slice, or None if it is empty.

pub fn iter<'a>(&'a self) -> Iter<'a, u8>

Returns an iterator over the string.

pub fn iter_mut<'a>(&'a mut self) -> IterMut<'a, u8>

Returns an iterator that allows modifying each value.

pub fn windows<'a>(&'a self, size: usize) -> Windows<'a>

Returns an iterator over all contiguous windows of length size. The windows overlap. If the string is shorter than size, the iterator returns no values.

Similar to slice::windows().

pub fn chunks<'a>(&'a self, size: usize) -> Chunks<'a>

Returns an iterator over size bytes of the string at a time. The chunks do not overlap. If size does not divide the length of the slice, then the last chunk will not have length size.

Similar to slice::chunks().

pub fn chunks_mut<'a>(&'a mut self, size: usize) -> ChunksMut<'a>

Returns an iterator over size elements of the slice at a time. The chunks are mutable strings and do not overlap. If size does not divide the length of the slice, then the last chunk will not have length size.

Similar to slice::chunks_mut().

pub fn split_at(&self, mid: usize) -> (&ByteStr, &ByteStr)

Divides one string into two at an index.

The first will contain all indices from [0, mid) (excluding the index mid itself) and the second will contain all indices from [mid, len) (excluding the index len itself).

Similar to slice::split_at().

Panics

Panics if mid > len.

pub fn split_at_mut(&mut self, mid: usize) -> (&mut ByteStr, &mut ByteStr)

Divides one &mut string into two at an index.

The first will contain all indices from [0, mid) (excluding the index mid itself) and the second will contain all indices from [mid, len) (excluding the index len itself).

Similar to slice::split_at_mut().

Panics

Panics if mid > len.

pub fn split<'a, M: IntoMatcher>(&'a self, m: M) -> Split<'a, M::Matcher>

Returns an iterator over substrings of this string, separated by a matcher.

pub fn split_mut<'a, M: IntoMatcher>( &'a mut self, m: M, ) -> SplitMut<'a, M::Matcher>

Returns an iterator over mutable substrings of this string, separated by a matcher.

pub fn rsplit<'a, M: IntoMatcher>(&'a self, m: M) -> RSplit<'a, M::Matcher>

Returns an iterator over substrings of this string, separated by a matcher, starting at the end of the slice and working backwards.

pub fn rsplit_mut<'a, M: IntoMatcher>( &'a mut self, m: M, ) -> RSplitMut<'a, M::Matcher>

Returns an iterator over mutable substrings of this string, separated by a matcher, starting at the end of the slice and working backwards.

pub fn splitn<'a, M: IntoMatcher>( &'a self, n: usize, m: M, ) -> SplitN<'a, M::Matcher>

Returns an iterator over substrings of this string, separated by a matcher, returning at most n items.

If n substrings are returned, the last substring will contain the remainder of the string.

pub fn splitn_mut<'a, M: IntoMatcher>( &'a mut self, n: usize, m: M, ) -> SplitNMut<'a, M::Matcher>

Returns an iterator over mutable substrings of this string, separated by a matcher, returning at most n items.

If n substrings are returned, the last substring will contain the remainder of the string.

pub fn rsplitn<'a, M: IntoMatcher>( &'a self, n: usize, m: M, ) -> RSplitN<'a, M::Matcher>

Returns an iterator over substrings of this string, separated by a matcher and stating from the end of the string, returning at most n items.

If n substrings are returned, the last substring will contain the remainder of the string.

pub fn rsplitn_mut<'a, M: IntoMatcher>( &'a mut self, n: usize, m: M, ) -> RSplitNMut<'a, M::Matcher>

Returns an iterator over mutable substrings of this string, separated by a matcher and stating from the end of the string, returning at most n items.

If n substrings are returned, the last substring will contain the remainder of the string.

pub fn matches<'a, M: IntoMatcher>(&'a self, m: M) -> Matches<'a, M::Matcher>

Returns an iterator over the disjoint matches within the given string.

pub fn matches_mut<'a, M: IntoMatcher>( &'a mut self, m: M, ) -> MatchesMut<'a, M::Matcher>

Returns an iterator over the mutable disjoint matches within the given string.

pub fn rmatches<'a, M: IntoMatcher>(&'a self, m: M) -> RMatches<'a, M::Matcher>

Returns an iterator over the disjoint matches within the given string, yielded in reverse order.

pub fn rmatches_mut<'a, M: IntoMatcher>( &'a mut self, m: M, ) -> RMatchesMut<'a, M::Matcher>

Returns an iterator over the mutable disjoint matches within the given string, yielded in reverse order.

pub fn match_indices<'a, M: IntoMatcher>( &'a self, m: M, ) -> MatchIndices<'a, M::Matcher>

Returns an iterator over the disjoint matches within the given string, as well as the index that the match starts at.

pub fn match_indices_mut<'a, M: IntoMatcher>( &'a mut self, m: M, ) -> MatchIndicesMut<'a, M::Matcher>

Returns an iterator over the mutable disjoint matches within the given string, as well as the index that the match starts at.

pub fn rmatch_indices<'a, M: IntoMatcher>( &'a self, m: M, ) -> RMatchIndices<'a, M::Matcher>

Returns an iterator over the disjoint matches within the given string, yielded in reverse order, as well as the index that the match starts at.

pub fn rmatch_indices_mut<'a, M: IntoMatcher>( &'a mut self, m: M, ) -> RMatchIndicesMut<'a, M::Matcher>

Returns an iterator over the mutable disjoint matches within the given string, yielded in reverse order, as well as the index that the match starts at.

pub fn contains<M: IntoMatcher>(&self, m: M) -> bool

Returns true if the string contains a substring that matches the given matcher.

pub fn starts_with<M: IntoMatcher>(&self, m: M) -> bool

Returns true if the string beginning a matches the given matcher.

pub fn ends_with<M: IntoMatcher>(&self, m: M) -> bool

Returns true if the string ending a matches the given matcher.

pub fn find<M: IntoMatcher>(&self, m: M) -> Option<usize>

Returns the byte index of the first character of self that matches the matcher or None it it doesn’t match.

pub fn rfind<M: IntoMatcher>(&self, m: M) -> Option<usize>

Returns the byte index of the last character of self that matches the matcher or None it it doesn’t match.

pub fn swap(&mut self, a: usize, b: usize)

Swaps two bytes in the string, indexed by a and b.

Panics

Panics if a or b are out of bounds.

pub fn reverse(&mut self)

Reverses the order of bytes in the slice.

pub fn copy_from_slice(&mut self, src: &[u8])

Copies all elements from src into self, using a memcpy.

The length of src must be the same as self.

pub fn copy_from_byte_str(&mut self, src: &ByteStr)

Copies all elements from src into self, using a memcpy.

The length of src must be the same as self.